@@ -1,4 +1,5 @@
-from typing import Union, List, Any, TYPE_CHECKING
+from typing import Union, List, Any, TYPE_CHECKING, Tuple, Dict
+
 if TYPE_CHECKING:
     from pyfileconf.selector.models.itemview import ItemView
 
@@ -8,4 +9,5 @@ Result = Any
 Results = List[Result]
 ResultOrResults = Union[Result, Results]
 StrOrView = Union[str, 'ItemView']
-RunnerArgs = Union[str, List[str], 'ItemView', List['ItemView']]
\ No newline at end of file
+RunnerArgs = Union[str, List[str], 'ItemView', List['ItemView']]
+IterativeResults = List[Tuple[Tuple[Dict[str, Any], ...], Tuple[Any]]]
\ No newline at end of file
