@@ -366,5 +366,11 @@ class Runner(ReprMixin):
             for key, value in d.items():
                 setattr(self._loaded_objects[section_path_str], key, value)
 
+    def refresh(self, section_path_str: str):
+        if section_path_str in self._loaded_objects:
+            del self._loaded_objects[section_path_str]
+
+        self._config.refresh(section_path_str)
+
     def _is_specific_class(self, obj: Any) -> bool:
         return self._all_specific_classes and isinstance(obj, self._all_specific_classes)  # type: ignore
